@@ -31,7 +31,7 @@ static void tictactoe_class_init          (TictactoeClass *klass);
 static void tictactoe_init                (Tictactoe      *ttt);
 static void tictactoe_toggle              (GtkWidget *widget, Tictactoe *ttt);
 
-static gint tictactoe_signals[LAST_SIGNAL] = { 0 };
+static guint tictactoe_signals[LAST_SIGNAL] = { 0 };
 
 GType
 tictactoe_get_type (void)
@@ -40,7 +40,7 @@ tictactoe_get_type (void)
 
   if (!ttt_type)
     {
-      static const GTypeInfo ttt_info =
+      const GTypeInfo ttt_info =
       {
 	sizeof (TictactoeClass),
 	NULL, /* base_init */
