@@ -23,13 +23,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
-#define GDK_PIXBUF_COMPILATION
+#define GDK_PIXBUF_C_COMPILATION
 #include "gdk-pixbuf.h"
 #include "gdk-pixbuf-private.h"
+/* Include the marshallers */
+#include <glib-object.h>
+#include "gdk-pixbuf-marshal.c"
 #include "gdk-pixbuf-alias.h"
 
 static void gdk_pixbuf_finalize     (GObject        *object);
@@ -56,7 +59,7 @@ enum
   PROP_PIXELS
 };
 
-G_DEFINE_TYPE(GdkPixbuf, gdk_pixbuf, G_TYPE_OBJECT)
+G_DEFINE_TYPE (GdkPixbuf, gdk_pixbuf, G_TYPE_OBJECT)
 
 static void 
 gdk_pixbuf_init (GdkPixbuf *pixbuf)
@@ -188,7 +191,7 @@ gdk_pixbuf_finalize (GObject *object)
  *
  * Return value: The same as the @pixbuf argument.
  *
- * Deprecated: Use g_object_ref().
+ * Deprecated: 2.0: Use g_object_ref().
  **/
 GdkPixbuf *
 gdk_pixbuf_ref (GdkPixbuf *pixbuf)
@@ -202,7 +205,7 @@ gdk_pixbuf_ref (GdkPixbuf *pixbuf)
  *
  * Removes a reference from a pixbuf. 
  *
- * Deprecated: Use g_object_unref().
+ * Deprecated: 2.0: Use g_object_unref().
  **/
 void
 gdk_pixbuf_unref (GdkPixbuf *pixbuf)
@@ -221,11 +224,11 @@ free_buffer (guchar *pixels, gpointer data)
 
 /**
  * gdk_pixbuf_new:
- * @colorspace: Color space for image.
- * @has_alpha: Whether the image should have transparency information.
- * @bits_per_sample: Number of bits per color sample.
- * @width: Width of image in pixels.
- * @height: Height of image in pixels.
+ * @colorspace: Color space for image
+ * @has_alpha: Whether the image should have transparency information
+ * @bits_per_sample: Number of bits per color sample
+ * @width: Width of image in pixels, must be > 0
+ * @height: Height of image in pixels, must be > 0
  *
  * Creates a new #GdkPixbuf structure and allocates a buffer for it.  The 
  * buffer has an optimal rowstride.  Note that the buffer is not cleared;
@@ -251,9 +254,6 @@ gdk_pixbuf_new (GdkColorspace colorspace,
 	g_return_val_if_fail (width > 0, NULL);
 	g_return_val_if_fail (height > 0, NULL);
 
-        if (width <= 0 || height <= 0)
-                return NULL;
-
 	channels = has_alpha ? 4 : 3;
         rowstride = width * channels;
         if (rowstride / channels != width || rowstride + 3 < 0) /* overflow */
@@ -291,7 +291,7 @@ gdk_pixbuf_copy (const GdkPixbuf *pixbuf)
 	guchar *buf;
 	int size;
 
-	g_return_val_if_fail (pixbuf != NULL, NULL);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
 
 	/* Calculate a semi-exact size.  Here we copy with full rowstrides;
 	 * maybe we should copy each row individually with the minimum
@@ -385,7 +385,7 @@ gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
 GdkColorspace
 gdk_pixbuf_get_colorspace (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, GDK_COLORSPACE_RGB);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), GDK_COLORSPACE_RGB);
 
 	return pixbuf->colorspace;
 }
@@ -401,7 +401,7 @@ gdk_pixbuf_get_colorspace (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_n_channels (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->n_channels;
 }
@@ -417,7 +417,7 @@ gdk_pixbuf_get_n_channels (const GdkPixbuf *pixbuf)
 gboolean
 gdk_pixbuf_get_has_alpha (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, FALSE);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), FALSE);
 
 	return pixbuf->has_alpha ? TRUE : FALSE;
 }
@@ -433,7 +433,7 @@ gdk_pixbuf_get_has_alpha (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->bits_per_sample;
 }
@@ -451,7 +451,7 @@ gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf)
 guchar *
 gdk_pixbuf_get_pixels (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, NULL);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
 
 	return pixbuf->pixels;
 }
@@ -467,7 +467,7 @@ gdk_pixbuf_get_pixels (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_width (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->width;
 }
@@ -483,7 +483,7 @@ gdk_pixbuf_get_width (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_height (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->height;
 }
@@ -500,7 +500,7 @@ gdk_pixbuf_get_height (const GdkPixbuf *pixbuf)
 int
 gdk_pixbuf_get_rowstride (const GdkPixbuf *pixbuf)
 {
-	g_return_val_if_fail (pixbuf != NULL, -1);
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), -1);
 
 	return pixbuf->rowstride;
 }
@@ -508,11 +508,11 @@ gdk_pixbuf_get_rowstride (const GdkPixbuf *pixbuf)
 
 
 /* General initialization hooks */
-GDK_PIXBUF_VAR const guint gdk_pixbuf_major_version = GDK_PIXBUF_MAJOR;
-GDK_PIXBUF_VAR const guint gdk_pixbuf_minor_version = GDK_PIXBUF_MINOR;
-GDK_PIXBUF_VAR const guint gdk_pixbuf_micro_version = GDK_PIXBUF_MICRO;
+const guint gdk_pixbuf_major_version = GDK_PIXBUF_MAJOR;
+const guint gdk_pixbuf_minor_version = GDK_PIXBUF_MINOR;
+const guint gdk_pixbuf_micro_version = GDK_PIXBUF_MICRO;
 
-GDK_PIXBUF_VAR const char *gdk_pixbuf_version = GDK_PIXBUF_VERSION;
+const char *gdk_pixbuf_version = GDK_PIXBUF_VERSION;
 
 /* Error quark */
 GQuark
@@ -593,7 +593,15 @@ gdk_pixbuf_fill (GdkPixbuf *pixbuf,
  * @key: a nul-terminated string.
  * 
  * Looks up @key in the list of options that may have been attached to the
- * @pixbuf when it was loaded. 
+ * @pixbuf when it was loaded, or that may have been attached by another
+ * function using gdk_pixbuf_set_option().
+ *
+ * For instance, the ANI loader provides "Title" and "Artist" options. 
+ * The ICO, XBM, and XPM loaders provide "x_hot" and "y_hot" hot-spot 
+ * options for cursor definitions. The PNG loader provides the tEXt ancillary
+ * chunk key/value pairs as options. Since 2.12, the TIFF and JPEG loaders
+ * return an "orientation" option string that corresponds to the embedded 
+ * TIFF/Exif orientation tag (if present).
  * 
  * Return value: the value associated with @key. This is a nul-terminated 
  * string that should not be freed or %NULL if @key was not found.
@@ -753,11 +761,5 @@ gdk_pixbuf_get_property (GObject         *object,
           }
 }
 
-
-
-/* Include the marshallers */
-#include <glib-object.h>
-#include "gdk-pixbuf-marshal.c"
-
 #define __GDK_PIXBUF_C__
 #include "gdk-pixbuf-aliasdef.c"
