@@ -687,7 +687,7 @@ gdk_drawable_impl_quartz_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (GdkDrawableImplQuartzClass),
         (GBaseInitFunc) NULL,
