@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <gtk/gtk.h>
 
 #include "gtk/gtktreedatalist.h"
